@@ -45,6 +45,26 @@ test_that("random assignment", {
   expect_true(all(good_holdout))
 })
 
+test_that("repeated", {
+  skip_if_not(sf::sf_use_s2())
+  set.seed(11)
+  rs2 <- spatial_block_cv(ames_sf, repeats = 2)
+
+  same_data <-
+    purrr::map_lgl(rs2$splits, function(x) {
+      all.equal(x$data, ames_sf)
+    })
+  expect_true(all(same_data))
+
+  good_holdout <- purrr::map_lgl(
+    rs2$splits,
+    function(x) {
+      length(intersect(x$in_ind, x$out_id)) == 0
+    }
+  )
+  expect_true(all(good_holdout))
+})
+
 test_that("systematic assignment -- snake", {
   skip_if_not(sf::sf_use_s2())
   set.seed(11)
@@ -154,6 +174,7 @@ test_that("systematic assignment -- continuous", {
 })
 
 test_that("polygons are only assigned one fold", {
+  skip_if_not(sf::sf_use_s2())
   set.seed(11)
 
   rs1 <- spatial_block_cv(boston_canopy, method = "continuous")
@@ -190,6 +211,7 @@ test_that("polygons are only assigned one fold", {
 })
 
 test_that("blocks are filtered based on centroids", {
+  skip_if_not(sf::sf_use_s2())
   set.seed(123)
   rs1 <- spatial_block_cv(boston_canopy, v = 18, cellsize = 15000)
   expect_true(
@@ -251,6 +273,16 @@ test_that("bad args", {
     spatial_block_cv(boston_canopy, n = 200)
   )
 
+  set.seed(123)
+  expect_snapshot_error(
+    spatial_block_cv(boston_canopy, method = "continuous", repeats = 2)
+  )
+
+  set.seed(123)
+  expect_snapshot_error(
+    spatial_block_cv(boston_canopy, method = "snake", repeats = 2)
+  )
+
 })
 
 test_that("printing", {
