@@ -51,6 +51,36 @@ test_that("spatial_buffer_vfold_cv", {
   )
   expect_true(all(good_holdout))
 
+  set.seed(123)
+  rs1 <- spatial_buffer_vfold_cv(
+    ames_sf,
+    v = 2,
+    radius = NULL,
+    buffer = NULL,
+    repeats = 2
+  )
+  expect_identical(
+    names(rs1),
+    c("splits", "id", "id2")
+  )
+  expect_snapshot(rs1)
+  same_data <- map_lgl(
+    rs1$splits,
+    function(x) {
+      isTRUE(all.equal(x$data, ames_sf))
+    }
+  )
+  expect_true(all(same_data))
+
+  good_holdout <- map_lgl(
+    rs1$splits,
+    function(x) {
+      length(intersect(x$in_ind, x$out_id)) == 0
+    }
+  )
+  expect_true(all(good_holdout))
+
+
 })
 
 test_that("spatial_leave_location_out_cv", {
@@ -84,6 +114,36 @@ test_that("spatial_leave_location_out_cv", {
   )
   expect_true(all(good_holdout))
 
+  set.seed(123)
+  rs1 <- spatial_leave_location_out_cv(
+    ames_sf,
+    Neighborhood,
+    v = 2,
+    repeats = 2
+  )
+  same_data <- map_lgl(
+    rs1$splits,
+    function(x) {
+      isTRUE(all.equal(x$data, ames_sf))
+    }
+  )
+  expect_true(all(same_data))
+
+  good_holdout <- map_lgl(
+    rs1$splits,
+    function(x) {
+      length(intersect(x$in_ind, x$out_id)) == 0
+    }
+  )
+  expect_true(all(good_holdout))
+
+  expect_identical(
+    names(rs1),
+    c("splits", "id", "id2")
+  )
+  skip_if_not(getRversion() >= numeric_version("3.6.0"))
+  expect_snapshot(rs1)
+
 })
 
 test_that("bad args", {
@@ -142,6 +202,26 @@ test_that("bad args", {
     spatial_buffer_vfold_cv(boston_canopy, v = 683, buffer = NULL, radius = NULL)
   )
 
+  set.seed(123)
+  expect_snapshot_error(
+    spatial_buffer_vfold_cv(
+      boston_canopy,
+      v = 682,
+      buffer = NULL,
+      radius = NULL,
+      repeats = 2
+    )
+  )
+
+  set.seed(123)
+  expect_snapshot_error(
+    spatial_leave_location_out_cv(
+      ames_sf,
+      Neighborhood,
+      repeats = 2
+    )
+  )
+
 })
 
 test_that("printing", {
